@@ -11,17 +11,20 @@ extern "C" {
 #define R_CHECKS_LEVEL 2
 #define R_CRITICAL_ENABLED 0
 #define DEBUGGER 1
+#define WANT_ZIP 1
 #define HAVE_DECL_ADDR_NO_RANDOMIZE 1
 #ifdef __EMSCRIPTEN__
 #define HAVE_ARC4RANDOM_UNIFORM 0
 #else
-#define HAVE_ARC4RANDOM_UNIFORM 0
+#define HAVE_ARC4RANDOM_UNIFORM 1
 #endif
-#define HAVE_EXPLICIT_BZERO 0
+#define HAVE_EXPLICIT_BZERO 1
 #define HAVE_EXPLICIT_MEMSET 0
-#define HAVE_CLOCK_NANOSLEEP 0
-#define HAVE_SIGACTION 0
+#define HAVE_CLOCK_NANOSLEEP 1
+#define HAVE_SIGACTION 1
 #define WANT_THREADS 1
+#define WANT_QJS 1
+#define WANT_V35 0
 #define WANT_CAPSTONE 1
 #define HAVE_LINUX_CAN_H 1
 #define R2_USE_NEW_ABI 0
@@ -50,6 +53,7 @@ extern "C" {
 #define R2_ETCDIR "/etc"
 #define R2_LIBDIR "/usr/lib64"
 #define R2_BINDIR "/usr/bin"
+#define R2_MANDIR "/usr/share/man"
 #define R2_INCDIR "/usr/include"
 #define R2_DATDIR "/usr/share"
 #define R2_WWWROOT "@WWWROOT@"
@@ -60,7 +64,7 @@ extern "C" {
 #define R2_SDB "@SDB@"
 #define R2_ZIGNS "@ZIGNS@"
 #define R2_THEMES "@THEMES@"
-#define R2_FORTUNES R_JOIN_3_PATHS ("/usr/share", "doc", "radare2-5.9.6")
+#define R2_FORTUNES R_JOIN_3_PATHS ("/usr/share", "doc", "radare2-6.0.4")
 #define R2_FLAGS "@FLAGS@"
 #define R2_HUD "@HUD@"
 #else
@@ -68,6 +72,7 @@ extern "C" {
 #define R2_PREFIX "."
 #define R2_ETCDIR "etc"
 #define R2_BINDIR "bin"
+#define R2_MANDIR "man"
 #define R2_LIBDIR "lib"
 #define R2_INCDIR "include\\libr"
 #define R2_DATDIR "share"
@@ -80,6 +85,7 @@ extern "C" {
 #define R2_ETCDIR "/etc"
 #define R2_LIBDIR "/usr/lib64"
 #define R2_BINDIR "/usr/bin"
+#define R2_MANDIR "/usr/share/man"
 #define R2_INCDIR "/usr/include/libr"
 #define R2_DATDIR "/usr/share"
 #define R2_WWWROOT R2_DATDIR "/radare2/" R2_VERSION "/www"
@@ -92,7 +98,7 @@ extern "C" {
 #define R2_ZIGNS            R_JOIN_4_PATHS ("share", "radare2", R2_VERSION, "zigns")
 #define R2_THEMES           R_JOIN_4_PATHS ("share", "radare2", R2_VERSION, "cons")
 #define R2_FLAGS            R_JOIN_4_PATHS ("share", "radare2", R2_VERSION, "flag")
-#define R2_FORTUNES         R_JOIN_3_PATHS ("share", "doc", "radare2-5.9.6")
+#define R2_FORTUNES         R_JOIN_3_PATHS ("share", "doc", "radare2-6.0.4")
 #define R2_HUD              R_JOIN_4_PATHS ("share", "radare2", R2_VERSION, "hud")
 #endif
 
